@@ -32,7 +32,7 @@
 #include <stdint.h>
 
 class CPUFreqd: public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
