@@ -71,7 +71,7 @@ void SourceListItem::initItem(){
 	//setText(1, mSource->getName());
 	//item->setText(2, source->getDescription());
 
-	connect(mSource, TQT_SIGNAL(enabledChanged(bool, Source*)), this, TQT_SLOT(setEnabled(bool)));
+	connect(mSource, TQ_SIGNAL(enabledChanged(bool, Source*)), this, TQ_SLOT(setEnabled(bool)));
 	setOn(mSource->isEnabled());
 }
 
