@@ -30,7 +30,7 @@
  * @author Ken Werner
  */
 class SourceListItem : public TQObject, public TQCheckListItem {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
