@@ -31,7 +31,7 @@
  * @author Ken Werner
  */
 class ACPIThermalSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
