@@ -29,7 +29,7 @@
  * CpuinfoFreqSrc reads temperature values from /proc/cpuinfo
  */
 class CpuinfoFreqSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
