@@ -32,7 +32,7 @@ class KProcIO;
  * @author Ken Werner
  */
 class NVidiaThermalSrc : public LabelSource {
-	Q_OBJECT
+	TQ_OBJECT
 	 //macro which activates signals and slots (moc)
 public:
 	/**
